==> objectify-alpha_28.4.tgz: objectify-alpha_28.4/attic/add_more_spellings.c <==
/*
--             This file is part of the New World OS project
--                    Copyright (C) 2007 QRW Software
--           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
--                      http://www.qrwsoftware.com
--                      http://nwos.sourceforge.com
--
--   This program is free software: you can redistribute it and/or modify
--   it under the terms of the GNU General Public License as published by
--   the Free Software Foundation, either version 3 of the License, or
--   (at your option) any later version.
--
--   This program is distributed in the hope that it will be useful,
--   but WITHOUT ANY WARRANTY; without even the implied warranty of
--   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--   GNU General Public License for more details.
--
--   You should have received a copy of the GNU General Public License
--   along with this program, in the file LICENSE.  If not, see 
--   <http://www.gnu.org/licenses/>.
--
--   You can also contact me via paper mail at:
--
--      QRW Software
--      P.O. Box 27511
--      Salt Lake City, UT 84127-0511, USA.
--
--
-- $Log: add_more_spellings.c,v $
-- Revision 1.4  2008/03/28 13:46:54  jsedwards
-- Modified to get list of words from stdin instead of putting them in this
-- file and then recompiling.
--
-- Revision 1.3  2008/03/28 12:06:57  jsedwards
-- Changed to pass 'PUBLIC' to nwos_initialize_objectify and add test to
-- verify spelling doesn't already exist before trying to create it.
--
-- Revision 1.2  2007/07/07 22:31:07  jsedwards
-- Changed to add some other words.
--
-- Revision 1.1  2007/07/07 20:48:02  jsedwards
-- Initial version.
--
*/

/* This program adds spellings to the public objects. */


#include <ctype.h>
#include <stdio.h>

#include "../objectify_private.h"


int main(int argc, char* argv[])
{
    ObjRef root_obj_ref;
    int i;
    int j;
    ObjRef ref;
    char spelling[64];
    char msg[128];
    char buffer[1024];

    nwos_log_arguments(argc, argv);

    nwos_initialize_objectify(NULL, 0, 0, PUBLIC, NULL);

    root_obj_ref.id[0] = 0;
    root_obj_ref.id[1] = 0;
    root_obj_ref.id[2] = 0;
    root_obj_ref.id[3] = 1;

    nwos_set_root_object(&root_obj_ref);

    while (fgets(buffer, sizeof(buffer), stdin) != NULL)
    {
	i = 0;

	while (buffer[i] != '\0')
	{
	    while (isspace(buffer[i])) i++;

	    j = 0;

	    while (buffer[i] != '\0' && !isspace(buffer[i]))
	    {
		if (j < sizeof(spelling) - 1)
		{
		    spelling[j++] = buffer[i++];
		}
		else if (j == sizeof(spelling) - 1)
		{
		    spelling[j++] = '\0';
		    fprintf(stderr, "WARNING: spelling %s%c", spelling, buffer[i++]);
		}
		else
		{
		    fprintf(stderr, "%c", buffer[i++]);
		}
	    }

	    if (0 < j && j < sizeof(spelling))
	    {
		spelling[j] = '\0';

		for (j = 0; spelling[j] != '\0'; j++)
		{
		    if (!isalpha(spelling[j]))
		    {
			fprintf(stderr, "WARNING: spelling %s contains invalid character '%c', ignored\n", spelling, spelling[j]);
			break;
		    }

		    spelling[j] = tolower(spelling[j]);
		}

		if (spelling[j] == '\0')
		{
		    if (nwos_find_public_spelling(spelling, &ref))
		    {
			fprintf(stderr, "WARNING: spelling %s already exists\n", spelling);
		    }
		    else
		    {
			snprintf(msg, sizeof(msg), "Creating spelling: %s", spelling);
			nwos_log(msg);
			printf("%s\n", msg);
		    }

		    nwos_create_public_spelling(spelling, &ref);
		}
	    }
	    else if (j == sizeof(spelling))
	    {
		fprintf(stderr, " is too long, ignored\n");
	    }
	}
    }

    if (ferror(stdin))
    {
	perror("reading stdin");
    }

    nwos_terminate_objectify();

    return 0;
}

==> objectify-alpha_29.8.tgz: objectify-alpha_29.8/attic/add_more_spellings.c <==
/*
--             This file is part of the New World OS project
--                 Copyright (C) 2007-2008  QRW Software
--           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
--                      http://www.qrwsoftware.com
--                      http://nwos.sourceforge.com
--
--   This program is free software: you can redistribute it and/or modify
--   it under the terms of the GNU General Public License as published by
--   the Free Software Foundation, either version 3 of the License, or
--   (at your option) any later version.
--
--   This program is distributed in the hope that it will be useful,
--   but WITHOUT ANY WARRANTY; without even the implied warranty of
--   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--   GNU General Public License for more details.
--
--   You should have received a copy of the GNU General Public License
--   along with this program, in the file LICENSE.  If not, see 
--   <http://www.gnu.org/licenses/>.
--
--   You can also contact me via paper mail at:
--
--      QRW Software
--      P.O. Box 27511
--      Salt Lake City, UT 84127-0511, USA.
--
--
-- $Log: add_more_spellings.c,v $
-- Revision 1.6  2008/09/01 00:22:56  jsedwards
-- Fix year in copyright.  NO code changes.
--
-- Revision 1.5  2008/08/31 18:25:42  jsedwards
-- Change for new parameters to nwos_initialize_objectify without key stuff
-- and eliminate calle to nwos_set_root_object because initialize does that now.
--
-- Revision 1.4  2008/03/28 13:46:54  jsedwards
-- Modified to get list of words from stdin instead of putting them in this
-- file and then recompiling.
--
-- Revision 1.3  2008/03/28 12:06:57  jsedwards
-- Changed to pass 'PUBLIC' to nwos_initialize_objectify and add test to
-- verify spelling doesn't already exist before trying to create it.
--
-- Revision 1.2  2007/07/07 22:31:07  jsedwards
-- Changed to add some other words.
--
-- Revision 1.1  2007/07/07 20:48:02  jsedwards
-- Initial version.
--
*/

/* This program adds spellings to the public objects. */


#include <ctype.h>
#include <stdio.h>

#include "../objectify_private.h"


int main(int argc, char* argv[])
{
    int i;
    int j;
    ObjRef ref;
    char spelling[64];
    char msg[128];
    char buffer[1024];

    nwos_log_arguments(argc, argv);

    nwos_initialize_objectify(PUBLIC, NULL);


    while (fgets(buffer, sizeof(buffer), stdin) != NULL)
    {
	i = 0;

	while (buffer[i] != '\0')
	{
	    while (isspace(buffer[i])) i++;

	    j = 0;

	    while (buffer[i] != '\0' && !isspace(buffer[i]))
	    {
		if (j < sizeof(spelling) - 1)
		{
		    spelling[j++] = buffer[i++];
		}
		else if (j == sizeof(spelling) - 1)
		{
		    spelling[j++] = '\0';
		    fprintf(stderr, "WARNING: spelling %s%c", spelling, buffer[i++]);
		}
		else
		{
		    fprintf(stderr, "%c", buffer[i++]);
		}
	    }

	    if (0 < j && j < sizeof(spelling))
	    {
		spelling[j] = '\0';

		for (j = 0; spelling[j] != '\0'; j++)
		{
		    if (!isalpha(spelling[j]))
		    {
			fprintf(stderr, "WARNING: spelling %s contains invalid character '%c', ignored\n", spelling, spelling[j]);
			break;
		    }

		    spelling[j] = tolower(spelling[j]);
		}

		if (spelling[j] == '\0')
		{
		    if (nwos_find_public_spelling(spelling, &ref))
		    {
			fprintf(stderr, "WARNING: spelling %s already exists\n", spelling);
		    }
		    else
		    {
			snprintf(msg, sizeof(msg), "Creating spelling: %s", spelling);
			nwos_log(msg);
			printf("%s\n", msg);
		    }

		    nwos_create_public_spelling(spelling, &ref);
		}
	    }
	    else if (j == sizeof(spelling))
	    {
		fprintf(stderr, " is too long, ignored\n");
	    }
	}
    }

    if (ferror(stdin))
    {
	perror("reading stdin");
    }

    nwos_terminate_objectify();

    return 0;
}
